@@ -4,7 +4,7 @@ static char rcsid[] = "$Id: arg.c 900 2008-01-05 01:13:26Z hubert@u.washington.e
 
 /*
  * ========================================================================
- * Copyright 2013-2020 Eduardo Chappa
+ * Copyright 2013-2021 Eduardo Chappa
  * Copyright 2006-2008 University of Washington
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
@@ -87,7 +87,8 @@ static char args_err_missing_client_id[] =	N_("missing client-id name. Example:
 static char args_err_missing_client_secret[] =	N_("missing client-secret name. Example: -xoauth2-client-secret V56i0fa_");
 static char args_err_missing_tenant[] =	N_("missing tenant value. Example: -xoauth2-tenant common");
 static char args_err_missing_user[] =	N_("missing username value. Example: -xoauth2-user user@example.com");
-static char args_err_missing_xoauth_option[] =  N_("at least one of the arguments -xoauth2-server, or -xoauth2-client-id, xoauth2-tenant, or -xoauth2-client-secret is missing.");
+static char args_err_missing_flow[] =	N_("missing flow. Example: -xoauth2-client-flow Authorize");
+static char args_err_missing_xoauth_option[] =  N_("you must set all options -xoauth2-server, -xoauth2-client-id and -xoauth2-client-secret if you use any of them");
 
 static char *args_pine_args[] = {
 N_("Possible Starting Arguments for Alpine program:"),
@@ -107,7 +108,7 @@ N_("\t\toption on the command line"),
 N_(" -bail\t\tExit if pinerc file doesn't already exist"),
 #ifdef	DEBUG
 N_(" -d n\t\tDebug - set debug level to 'n', or use the following:"),
-N_(" -d keywords...\tflush,timestamp,imap=0..4,tcp,numfiles=0..31,verbose=0..9"),
+N_(" -d keywords...\tflush,timestamp,imap=0..4,tcp,http,numfiles=0..31,verbose=0..9"),
 #endif
 N_(" -f <folder>\tFolder - give folder name to open"),
 N_(" -c <number>\tContext - which context to apply to -f arg"),
@@ -184,6 +185,10 @@ N_(" -xoauth2-server <value>"),
 N_(" -xoauth2-client-id <value>"),
 N_(" -xoauth2-client-secret <value>"),
 N_("\tNote: All of -xoauth options above must be used, if any of them is used"),
+N_(" -xoauth2-tenant <value>"),
+N_(" -xoauth2-user <value>"),
+N_(" -xoauth2-flow <value>"),
+N_("\tNote: The previous two options are optional and if not used, Alpine resorts to their default values"),
 " -<option>=<value>   Assign <value> to the pinerc option <option>",
 "\t\t     e.g. -signature-file=sig1",
 "\t\t     e.g. -color-style=no-color",
@@ -617,12 +622,12 @@ Loop: while(--ac > 0)
 		  do_version = 1;
 		  goto Loop;
 	      }
-	      else if(strcmp(*av, "xoauth2-server") == 0){
+	      else if(strcmp(*av, "xoauth2-server") == 0 || strcmp(*av, "x-s") == 0){
 		  if(--ac){
 		      if((str = *++av) != NULL){
 			  if(x.name)
 			     fs_give((void **) &x.name);
-			  x.name = cpystr(str);
+			  x.name = (unsigned char *) cpystr(str);
 		      }
 		  }
 		  else{
@@ -631,7 +636,7 @@ Loop: while(--ac > 0)
 		  }
 		  goto Loop;
 	      }
-	      else if(strcmp(*av, "xoauth2-client-id") == 0){
+	      else if(strcmp(*av, "xoauth2-client-id") == 0 || strcmp(*av, "x-c-i") == 0){
 		  if(--ac){
 		      if((str = *++av) != NULL){
 			  if(x.client_id)
@@ -645,7 +650,7 @@ Loop: while(--ac > 0)
 		  }
 		  goto Loop;
 	      }
-	      else if(strcmp(*av, "xoauth2-client-secret") == 0){
+	      else if(strcmp(*av, "xoauth2-client-secret") == 0 || strcmp(*av, "x-c-s") == 0){
 		  if(--ac){
 		      if((str = *++av) != NULL){
 			  if(x.client_secret)
@@ -659,7 +664,7 @@ Loop: while(--ac > 0)
 		  }
 		  goto Loop;
 	      }
-	      else if(strcmp(*av, "xoauth2-tenant") == 0){
+	      else if(strcmp(*av, "xoauth2-tenant") == 0 || strcmp(*av, "x-t") == 0){
 		  if(--ac){
 		      if((str = *++av) != NULL){
 			  if(x.tenant)
@@ -673,7 +678,7 @@ Loop: while(--ac > 0)
 		  }
 		  goto Loop;
 	      }
-	      else if(strcmp(*av, "xoauth2-user") == 0){
+	      else if(strcmp(*av, "xoauth2-user") == 0 || strcmp(*av, "x-u") == 0){
 		  if(--ac){
 		      if((str = *++av) != NULL){
 			  if(x.users)
@@ -687,6 +692,20 @@ Loop: while(--ac > 0)
 		  }
 		  goto Loop;
 	      }
+	      else if(strcmp(*av, "xoauth2-flow") == 0 || strcmp(*av, "x-f") == 0){
+		  if(--ac){
+		      if((str = *++av) != NULL){
+			  if(x.flow)
+			     fs_give((void **) &x.flow);
+			  x.flow = cpystr(str);
+		      }
+		  }
+		  else{
+		      display_args_err(_(args_err_missing_flow), NULL, 1);
+		      ++usage;
+		  }
+		  goto Loop;
+	      }
 #ifdef	_WINDOWS
 	      else if(strcmp(*av, "install") == 0){
 		  pine_state->install_flag = 1;
@@ -1028,6 +1047,12 @@ Loop: while(--ac > 0)
 	}
     }
 
+    if((x.name || x.client_id || x.client_secret)
+	&& !(x.name && x.client_id && x.client_secret)){
+	display_args_err(_(args_err_missing_xoauth_option), NULL, 1);
+	++usage;
+    }
+
     if(((do_conf ? 1 : 0)+(pinerc_file ? 1 : 0)) > 1){
 	display_args_err(_("May only have one of -conf and -pinerc"),
 			 NULL, 1);
@@ -1048,6 +1073,7 @@ Loop: while(--ac > 0)
 	if(tmp1){
 	  sprintf(tmp1,"%s=%s", ps_global->vars[V_XOAUTH2_INFO].name, tmp2);
           pinerc_cmdline_opt(tmp1);
+	  set_current_val(&ps_global->vars[V_XOAUTH2_INFO], TRUE, TRUE);
 	  fs_give((void **) &tmp1);
 	}
 	fs_give((void **) &tmp2);
@@ -1144,6 +1170,10 @@ process_debug_str(char *debug_str)
 			|| struncmp(*p, "tcpdebug", 8) == 0){
 		    ps_global->debug_tcp = 1;
 		}
+		else if(struncmp(*p, "http", 4) == 0 
+			|| struncmp(*p, "httpdebug", 9) == 0){
+		    ps_global->debug_http = 1;
+		}
 		else if(struncmp(*p, "verbose", 7) == 0){
 		    q = *p + 7;
 		    if(!*q || !*(q+1) || *q != '=' ||
@@ -1213,8 +1243,10 @@ process_debug_str(char *debug_str)
 	}
 	else{
 	    debug = atoi(debug_str);
-	    if(debug > 9)
+	    if(debug > 9){
 	      ps_global->debug_imap = 5;
+	      ps_global->debug_http = 1;
+	    }
 	    else if(debug > 7)
 	      ps_global->debug_imap = 4;
 	    else if(debug > 6)
