@@ -5,7 +5,7 @@ static char rcsid[] = "$Id: context.c 769 2007-10-24 00:15:40Z hubert@u.washingt
 /*
  * ========================================================================
  * Copyright 2006-2007 University of Washington
- * Copyright 2013-2020 Eduardo Chappa
+ * Copyright 2013-2021 Eduardo Chappa
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -580,7 +580,7 @@ context_config_shuffle(struct pine *ps, CONF_S **cl)
     int	      n = 0, cmd, i1, i2, count = 0, insert_num, starting_varmem;
     int       news_problem = 0, deefault = 0;
     ESCKEY_S  ekey[3];
-    CONTEXT_S *cur_ctxt, *other_ctxt;
+    CONTEXT_S *cur_ctxt, *other_ctxt = NULL;
     char     *tmp, **lval, **lval1, **lval2;
     struct variable *cur_var, *other_var;
 
