@@ -5,7 +5,7 @@ static char rcsid[] = "$Id: debuging.c 900 2008-01-05 01:13:26Z hubert@u.washing
 /*
  * ========================================================================
  * Copyright 2006-2008 University of Washington
- * Copyright 2013-2020 Eduardo Chappa
+ * Copyright 2013-2021 Eduardo Chappa
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -72,25 +72,58 @@ init_debug(void)
 {
     char nbuf[5];
     char newfname[MAXPATH+1], filename[MAXPATH+1], *dfile = NULL;
+    char basename[MAXPATH+1];
+#ifdef DEBUGFILEEXT
+    struct stat sbuf;
+#endif /* DEBUGFILEEXT */
     int i, fd;
 
-    if(!((debug || ps_global->debug_imap || ps_global->debug_tcp) &&  ps_global->write_debug_file))
+    if(!((debug || ps_global->debug_imap || ps_global->debug_tcp || ps_global->debug_http) &&  ps_global->write_debug_file))
       return;
 
+    build_path(basename, ps_global->home_dir, DEBUGFILE, sizeof(basename));
+#ifdef DEBUGFILEEXT
+    if (ps_global->debug_nfiles > 0) {
+	strncpy(filename, basename, sizeof(filename) - 1);
+	filename[sizeof(filename) - 1] = '\0';
+	strncat(filename, DEBUGFILEEXT, sizeof(filename) - 1 - strlen(filename));
+	snprintf(nbuf, sizeof(nbuf), "%d", ps_global->debug_nfiles);
+	strncat(filename, nbuf, sizeof(filename) - 1 - strlen(filename));
+	our_unlink(filename);
+    }
+#endif /* DEBUGFILEEXT */
+
     for(i = ps_global->debug_nfiles - 1; i > 0; i--){
-        build_path(filename, ps_global->home_dir, DEBUGFILE, sizeof(filename));
-        strncpy(newfname, filename, sizeof(newfname)-1);
-	newfname[sizeof(newfname)-1] = '\0';
+        strncpy(filename, basename, sizeof(filename)-1);
+	filename[sizeof(filename)-1] = '\0';
 	snprintf(nbuf, sizeof(nbuf), "%d", i);
-        strncat(filename, nbuf, sizeof(filename)-1-strlen(filename));
+	strncat(filename, nbuf, sizeof(filename)-1-strlen(filename));
+#ifdef DEBUGFILEEXT
+        strncat(filename, DEBUGFILEEXT, sizeof(filename)-1-strlen(filename));
+	if (our_stat(filename, &sbuf) < 0){
+	    strncpy(filename, basename, sizeof(filename)-1);
+	    filename[sizeof(filename)-1] = '\0';
+	    strncat(filename, DEBUGFILEEXT, sizeof(filename)-1-strlen(filename));
+	    strncat(filename, nbuf, sizeof(filename)-1-strlen(filename));
+	}
+#endif  /* DEBUGFILEEXT */
+	strncpy(newfname, basename, sizeof(newfname)-1);
+	newfname[sizeof(newfname)-1] = '\0';
 	snprintf(nbuf, sizeof(nbuf), "%d", i+1);
         strncat(newfname, nbuf, sizeof(newfname)-1-strlen(newfname));
+#ifdef DEBUGFILEEXT
+        strncat(newfname, DEBUGFILEEXT, sizeof(newfname)-1-strlen(newfname));
+#endif /* DEBUGFILEEXT */
         (void)rename_file(filename, newfname);
     }
 
-    build_path(filename, ps_global->home_dir, DEBUGFILE, sizeof(filename)-1);
+    strncpy(filename, basename, sizeof(filename) - 1);
+    filename[sizeof(filename) - 1] = '\0';
     strncat(filename, "1", sizeof(filename)-1-strlen(filename));
     filename[sizeof(filename)-1] = '\0';
+#ifdef DEBUGFILEEXT
+    strncat(filename, DEBUGFILEEXT, sizeof(filename) - 1 - strlen(filename));
+#endif /* DEBUGFILEEXT */
 
     debugfile = NULL;
     dfile = filename;
@@ -130,7 +163,8 @@ init_debug(void)
 	dprint((0, "Starting after the reading_pinerc calls, the data in this file should\nbe encoded as UTF-8. Before that it will be in the user's native charset.\n"));
 	if(dfile && (debug > DEFAULT_DEBUG ||
 		     ps_global->debug_imap > 0 ||
-		     ps_global->debug_tcp > 0)){
+		     ps_global->debug_tcp > 0 ||
+		     ps_global->debug_http > 0)){
 	    snprintf(newfname, sizeof(newfname), "Debug file: %s (level=%d imap=%d)", dfile,
 		     debug, ps_global->debug_imap);
 	    init_error(ps_global, SM_ORDER, 3, 5, newfname);
@@ -152,7 +186,7 @@ init_debug(void)
 void
 save_debug_on_crash(FILE *dfile, int (*keystrokes) (int *, char *, size_t))
 {
-    char nbuf[5], crashfile[MAXPATH+1], filename[MAXPATH+1];
+    char nbuf[11], crashfile[MAXPATH+1], filename[MAXPATH+1];
     int i;
     struct stat dbuf, tbuf;
     time_t now = time((time_t *)0);
@@ -258,6 +292,7 @@ do_debug(FILE *debug_fp)
     if(debug <= DEFAULT_DEBUG
        && !ps_global->debug_flush
        && !ps_global->debug_tcp
+       && !ps_global->debug_http
        && !ps_global->debug_timestamp
        && !ps_global->debug_imap
        && ok
