@@ -4,7 +4,7 @@ static char rcsid[] = "$Id: rpdump.c 1074 2008-06-04 00:08:43Z hubert@u.washingt
 
 /*
  * ========================================================================
- * Copyright 2013-2020 Eduardo Chappa
+ * Copyright 2013-2021 Eduardo Chappa
  * Copyright 2006-2008 University of Washington
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
@@ -766,7 +766,8 @@ opt_enter(string, field_len, prompt, flags)
 	    char *p;
 
 	    fputs(prompt, stdout);
-	    fgets(string, field_len, stdin);
+	    if(!fgets(string, field_len, stdin))
+	       return_v = 1;	/* cancel? */
 	    string[field_len-1] = '\0';
 	    if((p = strpbrk(string, "\r\n")) != NULL)
 	      *p = '\0';
@@ -804,7 +805,8 @@ wantto(question, dflt, on_ctrl_C)
 
     while(!ret){
       fprintf(stdout, "%s? [%c]:", question, dflt);
-      fgets(rep, sizeof(rep), stdin);
+      if(!fgets(rep, sizeof(rep), stdin))
+	*rep = '\0';
       if((p = strpbrk(rep, "\r\n")) != NULL)
 	*p = '\0';
       switch(*rep){
