@@ -5,7 +5,7 @@ static char rcsid[] = "$Id: status.c 840 2007-12-01 01:34:49Z hubert@u.washingto
 /*
  * ========================================================================
  * Copyright 2006-2007 University of Washington
- * Copyright 2013-2020 Eduardo Chappa
+ * Copyright 2013-2021 Eduardo Chappa
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -971,6 +971,8 @@ status_message_write(char *message, int from_alarm_handler)
 	      EndInverse();
 	}
 	else{
+	    int width = (int) utf8_width(newstatusbuf);
+
 	    if(pico_usingcolor())
 	      lastc = pico_get_cur_color();
 
@@ -982,6 +984,13 @@ status_message_write(char *message, int from_alarm_handler)
 
 	    ClearLine(row);
 
+	    if (width > ps_global->ttyo->screen_cols)
+	      col = 0;
+	    else
+	      col = (ps_global->ttyo->screen_cols - width) / 2;
+
+	    MoveCursor(row, col);	/* so Inverse will be set correctly */
+
 	    if(pico_usingcolor() && VAR_STATUS_FORE_COLOR &&
 	       VAR_STATUS_BACK_COLOR &&
 	       pico_is_good_color(VAR_STATUS_FORE_COLOR) &&
@@ -1000,7 +1009,7 @@ status_message_write(char *message, int from_alarm_handler)
 		StartInverse();
 	    }
 
-	    col = Centerline(row, newstatusbuf);
+	    PutLine0(row, col, newstatusbuf);
 
 	    if(lastc){
 		(void)pico_set_colorp(lastc, PSC_NONE);
