@@ -1,5 +1,5 @@
 /*
- * Copyright 2016 - Eduardo Chappa
+ * Copyright 2016 - 2010 Eduardo Chappa
  * Last Modified: August 11, 2016
  */
 /* ========================================================================
@@ -44,8 +44,8 @@ typedef struct {
 /* Prototypes */
 
 long auth_md5_valid (void);
-long auth_md5_client (authchallenge_t challenger,authrespond_t responder,
-		      char *service,NETMBX *mb,void *stream,
+long auth_md5_client (authchallenge_t challenger,authrespond_t responder,char *base,
+		      char *service,NETMBX *mb,void *stream, unsigned long port,
 		      unsigned long *trial,char *user);
 char *auth_md5_server (authresponse_t responder,int argc,char *argv[]);
 char *auth_md5_pwd (char *user);
@@ -95,8 +95,8 @@ long auth_md5_valid (void)
  * Returns: T if success, NIL otherwise, number of trials incremented if retry
  */
 
-long auth_md5_client (authchallenge_t challenger,authrespond_t responder,
-		      char *service,NETMBX *mb,void *stream,
+long auth_md5_client (authchallenge_t challenger,authrespond_t responder,char *base,
+		      char *service,NETMBX *mb,void *stream, unsigned long port,
 		      unsigned long *trial,char *user)
 {
   char *pwd = NIL,hshbuf[2*MD5DIGLEN + 1];
@@ -108,7 +108,7 @@ long auth_md5_client (authchallenge_t challenger,authrespond_t responder,
     mm_login (mb,user, &pwd,*trial);
     if (!pwd) {		/* user requested abort */
       fs_give ((void **) &challenge);
-      (*responder) (stream,NIL,0);
+      (*responder) (stream,NIL,NIL,0);
       *trial = 0;		/* cancel subsequent attempts */
       ret = LONGT;		/* will get a BAD response back */
     }
@@ -118,7 +118,7 @@ long auth_md5_client (authchallenge_t challenger,authrespond_t responder,
 						pwd,strlen (pwd)));
       fs_give ((void **) &challenge);
 				/* send credentials, allow retry if OK */
-      if ((*responder) (stream,tmp,strlen (tmp))) {
+      if ((*responder) (stream,NIL,tmp,strlen (tmp))) {
 	if ((challenge = (*challenger) (stream,&clen)) != NULL)
 	  fs_give ((void **) &challenge);
 	else {
