@@ -160,6 +160,8 @@
 #define SET_OA2CLIENTINFO (long) 172
 #define GET_OA2DEVICEINFO (long) 173
 #define SET_OA2DEVICEINFO (long) 174
+#define GET_HTTPDEBUG	  (long) 175
+#define SET_HTTPDEBUG	  (long) 176
 
 	/* 2xx: environment */
 #define GET_USERNAME (long) 201
@@ -246,6 +248,8 @@
 #define SET_ENCRYPTION_RANGE_MIN (long) 339
 #define GET_ENCRYPTION_RANGE_MAX (long) 340
 #define SET_ENCRYPTION_RANGE_MAX (long) 341
+#define GET_SSLCIPHERS	(long) 342
+#define SET_SSLCIPHERS	(long) 343
 
 	/* 4xx: network drivers */
 #define GET_MAXLOGINTRIALS (long) 400
@@ -304,6 +308,8 @@
 #define SET_IDLETIMEOUT (long) 453
 #define GET_FETCHLOOKAHEADLIMIT (long) 454
 #define SET_FETCHLOOKAHEADLIMIT (long) 455
+#define GET_ERASEPASSWORD	(long) 456
+#define SET_ERASEPASSWORD	(long) 457
 /* HTTP SUPPORT DEFINES THEIR OWN SET_ AND GET_ CONSTANTS (490..493). See http.h */
 
 	/* 5xx: local file drivers */
@@ -573,6 +579,7 @@
 #define PARSE (long) 3		/* mm_log parse error type */
 #define BYE (long) 4		/* mm_notify stream dying */
 #define TCPDEBUG (long) 5	/* mm_log TCP debug babble */
+#define HTTPDEBUG (long) 6	/* mm_log HTTP debug babble */
 
 
 /* Bits from mail_parse_flags().  Don't change these, since the header format
@@ -1411,6 +1418,7 @@ typedef ADDRESS *(*parsephrase_t) (char *phrase,char *end,char *host);
 typedef void *(*blocknotify_t) (int reason,void *data);
 typedef long (*kinit_t) (char *host,char *reason);
 typedef void (*sendcommand_t) (MAILSTREAM *stream,char *cmd,long flags);
+typedef void (*deletepwd_t) (NETMBX *mb,char *user);
 typedef char *(*newsrcquery_t) (MAILSTREAM *stream,char *mulname,char *name);
 typedef void (*getacl_t) (MAILSTREAM *stream,char *mailbox,ACLLIST *acl);
 typedef void (*listrights_t) (MAILSTREAM *stream,char *mailbox,char *id,
@@ -1693,6 +1701,8 @@ long mm_diskerror (MAILSTREAM *stream,long errcode,long serious);
 void mm_fatal (char *string);
 void *mm_cache (MAILSTREAM *stream,unsigned long msgno,long op);
 
+void delete_password (NETMBX *mb, char *user);
+
 extern STRINGDRIVER mail_string;
 void mail_versioncheck (char *version);
 void mail_link (DRIVER *driver);
@@ -1938,6 +1948,10 @@ int PFLUSH (void);
 #define OAUTH2_TOT_EQUIV        (OAUTH2_MAX_EQUIV + 2)
 #define OAUTH2_PARAM_NUMBER	(7)
 
+#define OA2_UNKNOWN	0x00	/* We do not know what method this client-id uses */
+#define OA2_DEVICE	0x01	/* Client ID obtained by client uses Device Method */
+#define OA2_AUTHORIZE	0x10	/* Client ID obtained by client uses Authorize Method */
+
 typedef enum {OA2_Id = 0,
 	      OA2_Secret,
 	      OA2_Tenant,
@@ -1992,6 +2006,7 @@ typedef struct oauth2_s {
    unsigned int first_time:1;	/* this is the first time we get credentials for this account */
    unsigned int require_secret:1;	/* this server requires a client-secret */
    int cancel_refresh_token;	/* ask client to cancel refresh token */
+   int flags;			/* options to register for this method */
 } OAUTH2_S;
 
 typedef struct deviceproc_s {
