@@ -1168,7 +1168,7 @@ long mbx_append (MAILSTREAM *stream,char *mailbox,append_t af,void *data)
 	  ret = NIL;		/* mark failure */
 	  break;
 	}
-	mail_date (tmp,&elt);	/* write preseved date */
+	mail_date (tmp,&elt);	/* write preserved date */
       }
       else internal_date (tmp);	/* get current date in IMAP format */
 				/* write header */
