@@ -76,6 +76,7 @@ static char *sslCApath = NIL;	/* non-standard CA path */
 static char *sslCAfile = NIL;	/* non-standard CA container */
 static char *sslAppCApath = NIL;  /* App SSL CA path */
 static char *sslAppCAfile = NIL;  /* App SSL CA container */
+static char *sslciphers = NIL;	 /* ciphers to negotiate with a SSL server */
 static short anonymous = NIL;	/* is anonymous */
 static short blackBox = NIL;	/* is a black box */
 static short closedBox = NIL;	/* is a closed box (uses chroot() jail) */
@@ -370,6 +371,13 @@ void *env_parameters (long function,void *value)
   case GET_SSLAPPCAFILE:
     ret = (void *) sslAppCAfile;
     break;
+  case SET_SSLCIPHERS:		/* this can be set null */
+    if (sslciphers) fs_give ((void **) &sslciphers);
+    sslciphers = value ? cpystr ((char *) value) : value;
+    break;
+  case GET_SSLCIPHERS:
+    ret = (void *) sslciphers;
+    break;
   case SET_LISTMAXLEVEL:
     list_max_level = (long) value;
   case GET_LISTMAXLEVEL:
