@@ -165,7 +165,8 @@ DRIVER mbxdriver = {
   mbx_expunge,			/* expunge deleted messages */
   mbx_copy,			/* copy messages to another mailbox */
   mbx_append,			/* append string message to mailbox */
-  NIL				/* garbage collect stream */
+  NIL,				/* garbage collect stream */
+  NIL				/* renew stream */
 };
 
 				/* prototype stream */
@@ -1168,7 +1169,7 @@ long mbx_append (MAILSTREAM *stream,char *mailbox,append_t af,void *data)
 	  ret = NIL;		/* mark failure */
 	  break;
 	}
-	mail_date (tmp,&elt);	/* write preseved date */
+	mail_date (tmp,&elt);	/* write preserved date */
       }
       else internal_date (tmp);	/* get current date in IMAP format */
 				/* write header */
