@@ -134,7 +134,8 @@ DRIVER newsdriver = {
   news_expunge,			/* expunge deleted messages */
   news_copy,			/* copy messages to another mailbox */
   news_append,			/* append string message to mailbox */
-  NIL				/* garbage collect stream */
+  NIL,				/* garbage collect stream */
+  NIL				/* renew stream */
 };
 
 				/* prototype stream */
