@@ -1,5 +1,5 @@
 /* ========================================================================
- * Copyright 2019 Eduardo Chappa
+ * Copyright 2019-2021 Eduardo Chappa
  * Copyright 2008-2009 Mark Crispin
  * ========================================================================
  */
@@ -395,7 +395,7 @@ static char *ssl_start_work (SSLSTREAM *stream,char *host,unsigned long flags)
   int minv, maxv;
   int masklow, maskhigh;
   char *s,*t,*err,tmp[MAILTMPLEN], buf[256];
-  char *CAfile, *CApath;
+  char *CAfile, *CApath, *ciphers;
   sslcertificatequery_t scq =
     (sslcertificatequery_t) mail_parameters (NIL,GET_SSLCERTIFICATEQUERY,NIL);
   sslclientcert_t scc =
@@ -414,6 +414,12 @@ static char *ssl_start_work (SSLSTREAM *stream,char *host,unsigned long flags)
   if (flags & NET_NOVALIDATECERT)
     SSL_CTX_set_verify (stream->context,SSL_VERIFY_NONE,NIL);
   else SSL_CTX_set_verify (stream->context,SSL_VERIFY_PEER,ssl_open_verify);
+				/* set cipher list */
+  ciphers = (char *) mail_parameters (NIL,GET_SSLCIPHERS,NIL);
+  if(ciphers != NIL
+     && *ciphers != '\0'
+     && !SSL_CTX_set_cipher_list (stream->context,ciphers))
+     return "No listed ciphers recognized";
 				/* if a non-standard path desired */
   CAfile = (char *) mail_parameters (NIL,GET_SSLCAFILE,NIL);
   CApath = (char *) mail_parameters (NIL,GET_SSLCAPATH,NIL);
@@ -462,16 +468,18 @@ static char *ssl_start_work (SSLSTREAM *stream,char *host,unsigned long flags)
   if (SSL_write (stream->con,"",0) < 0)
     return ssl_last_error ? ssl_last_error : "SSL negotiation failed";
 				/* need to validate host names? */
+  cert = SSL_get_peer_certificate (stream->con);
   if (!(flags & NET_NOVALIDATECERT) &&
-      (err = ssl_validate_cert (cert = SSL_get_peer_certificate (stream->con),
-				host))) {
+      (err = ssl_validate_cert (cert, host))) {
 				/* application callback */
     X509_NAME_oneline (X509_get_subject_name(cert), buf, sizeof(buf));
     if (scq) return (*scq) (err,host,cert ? buf : "???") ? NIL : "";
 				/* error message to return via mm_log() */
     sprintf (tmp,"*%.128s: %.255s",err,cert ? buf : "???");
+    X509_free(cert);
     return ssl_last_error = cpystr (tmp);
   }
+  X509_free(cert);
   return NIL;
 }
 
@@ -514,7 +522,7 @@ static char *ssl_validate_cert (X509 *cert,char *host)
 {
   int i,j,n, m = 0;
   char *s=NULL,*t,*ret = NIL;
-  void *ext;
+  void *ext = NIL;
   GENERAL_NAME *name;
   X509_NAME *cname;
   X509_NAME_ENTRY *e;
@@ -540,6 +548,7 @@ static char *ssl_validate_cert (X509 *cert,char *host)
 	 if ((name = sk_GENERAL_NAME_value (ext,i)) &&
 	    (name->type = GEN_DNS) && (s = name->d.ia5->data) &&
 	    ssl_compare_hostnames (host,s)) ret = NIL;
+     if(ext) GENERAL_NAMES_free(ext);
   }
 #endif /* OPENSSL_1_1_0 */
 				/* Method 2, use cname */
@@ -555,6 +564,7 @@ static char *ssl_validate_cert (X509 *cert,char *host)
 				/* host name matches pattern? */
 	   ret = ssl_compare_hostnames (host,s) ? NIL :
 		 "Server name does not match certificate";
+	   ext = NIL;
 				/* if mismatch, see if in extensions */
 	   if (ret && (ext = X509_get_ext_d2i (cert,NID_subject_alt_name,NIL,NIL)) &&
 		(n = sk_GENERAL_NAME_num (ext)))
@@ -563,6 +573,7 @@ static char *ssl_validate_cert (X509 *cert,char *host)
 		  if ((name = sk_GENERAL_NAME_value (ext,i)) &&
 		     (name->type = GEN_DNS) && (s = name->d.ia5->data) &&
 		     ssl_compare_hostnames (host,s)) ret = NIL;
+	  if(ext) GENERAL_NAMES_free(ext);
         }
      }
   }
