@@ -5,7 +5,7 @@ static char rcsid[] = "$Id: line.c 769 2007-10-24 00:15:40Z hubert@u.washington.
 /*
  * ========================================================================
  * Copyright 2006-2007 University of Washington
- * Copyright 2013-2020 Eduardo Chappa
+ * Copyright 2013-2021 Eduardo Chappa
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -70,7 +70,7 @@ long  pkbufremove(int, struct pkbuf *);
 LINE *
 lalloc(int used)
 {
-    register LINE   *lp;
+    register LINE   *lp = NULL;
     register int    size;
     EML             eml;
     static int      displayed = 0;
