@@ -5,7 +5,7 @@ static char rcsid[] = "$Id: altedit.c 854 2007-12-07 17:44:43Z hubert@u.washingt
 /*
  * ========================================================================
  * Copyright 2006-2007 University of Washington
- * Copyright 2013-2020 Eduardo Chappa
+ * Copyright 2013-2021 Eduardo Chappa
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -109,7 +109,7 @@ alt_editor(int f, int n)
 
 	if(Pmaster->alt_ed){
 	    char **lp, *wsp, *path, fname[MAXPATH+1];
-	    int	   c;
+	    int	   c = '\0';
 
 	    for(lp = Pmaster->alt_ed; *lp && **lp; lp++){
 		if((wsp = strpbrk(*lp, " \t")) != NULL){
