@@ -5,7 +5,7 @@ static char rcsid[] = "$Id: shell.c 807 2007-11-09 01:21:33Z hubert@u.washington
 /*
  * ========================================================================
  * Copyright 2006-2007 University of Washington
- * Copyright 2013-2020 Eduardo Chappa
+ * Copyright 2013-2021 Eduardo Chappa
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -98,7 +98,7 @@ bktoshell(int f, int n)
 
     if(gmode&MDSPWN){
 	char *shell;
-	int   dummy;
+	int   dummy = 1;
 
 	vttidy();
 	movecursor(0, 0);
