@@ -5,7 +5,7 @@ static char rcsid[] = "$Id: bldaddr.c 769 2007-10-24 00:15:40Z hubert@u.washingt
 /*
  * ========================================================================
  * Copyright 2006-2007 University of Washington
- * Copyright 2013-2020 Eduardo Chappa
+ * Copyright 2013-2021 Eduardo Chappa
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -472,7 +472,7 @@ expand_address(BuildTo to, char *userdomain, char *localdomain, int *loop_detect
 	       int simple_verify, int *mangled)
 {
     size_t       domain_length, length;
-    ADDRESS     *adr, *a, *a_tail, *adr2, *a2, *a_temp, *wp_a;
+    ADDRESS     *adr, *a, *a_tail, *adr2 = NULL, *a2, *a_temp, *wp_a;
     AdrBk_Entry *abe, *abe2;
     char        *list, *l1, **l2;
     char        *tmp_a_string, *q;
