@@ -4,7 +4,7 @@ static char rcsid[] = "$Id: utf8.c 1184 2008-12-16 23:52:15Z hubert@u.washington
 
 /*
  * ========================================================================
- * Copyright 2013-2020 Eduardo Chappa
+ * Copyright 2013-2021 Eduardo Chappa
  * Copyright 2006-2008 University of Washington
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
@@ -125,6 +125,7 @@ pith_ucs4width(UCS ucs)
 int
 wtomb(char *dest, UCS ucs)
 {
+    int rv;
     /*
      * We believe that on modern unix systems wchar_t is a UCS-4 character.
      * That's the assumption here.
@@ -150,7 +151,14 @@ wtomb(char *dest, UCS ucs)
 	return(ret);
     }
     else
-      return(wcrtomb(dest, (wchar_t) ucs, NULL));
+#if defined(HAVE_WCRTOMB)
+       rv = wcrtomb(dest, (wchar_t) ucs, NULL);
+#elif defined(HAVE_WCTOMB)
+       rv = wctomb(dest, (wchar_t) ucs);
+#else
+       rv = -1;
+#endif
+   return rv;
 }
 
 
@@ -228,7 +236,7 @@ convert_to_utf8(char *str, char *fromcharset, int flags)
     char          *ret = NULL;
     char          *fcharset;
     SIZEDTEXT      src, result;
-    const CHARSET *cs;
+    const CHARSET *cs = NULL;
     int            try;
 
     src.data = (unsigned char *) str;
@@ -675,6 +683,49 @@ ucs4_to_utf8_cpystr_n(UCS *ucs4src, int ucs4src_len)
     return ((char *) ret);
 }
 
+/*
+ * Similar to above but copy what is possible to a
+ * string of a size at most the given retlen.
+ */
+char *
+ucs4_to_utf8_n_cpystr(UCS *ucs4src, int retlen)
+{
+    unsigned char *ret = NULL;
+    unsigned char *writeptr;
+    int            i, oldlen, len;
+
+    if(!ucs4src)
+      return NULL;
+
+    /*
+     * Over-allocate and then resize at the end.
+     */
+
+    /* count characters in source */
+    for(i = 0; ucs4src[i]; i++)
+      ;
+
+    ret = (unsigned char *) fs_get((6*i + 1) * sizeof(unsigned char));
+    memset(ret, 0, (6*i + 1) * sizeof(unsigned char));
+
+    writeptr = ret;
+    oldlen = len = 0;
+    for(i = 0; ucs4src[i] && (len < retlen); i++){
+      oldlen = len;
+      writeptr = utf8_put(writeptr, (unsigned long) ucs4src[i]);
+      len = strlen(ret);
+    }
+    if(len > retlen){
+      ret[oldlen] = '\0';
+      len = oldlen;
+    }
+
+    /* get rid of excess size */
+    fs_resize((void **) &ret, (len + 1) * sizeof(unsigned char));
+
+    return ((char *) ret);
+}
+
 
 #ifdef _WINDOWS
 /*
