@@ -4,7 +4,7 @@ static char rcsid[] = "$Id: detoken.c 769 2007-10-24 00:15:40Z hubert@u.washingt
 
 /*
  * ========================================================================
- * Copyright 2013-2020 Eduardo Chappa
+ * Copyright 2013-2021 Eduardo Chappa
  * Copyright 2006 University of Washington
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
@@ -144,7 +144,7 @@ detoken_src(char *src, int for_what, ENVELOPE *env, ACTION_S *role,
 	    REDRAFT_POS_S **redraft_pos, int *impl)
 {
     int   loopcnt = 25;		/* just in case, avoid infinite loop */
-    char *ret, *str1, *str2;
+    char *ret = NULL, *str1, *str2;
     int   done = 0;
 
     if(!src)
