@@ -5,7 +5,7 @@ static char rcsid[] = "$Id: news.c 769 2007-10-24 00:15:40Z hubert@u.washington.
 /*
  * ========================================================================
  * Copyright 2006-2007 University of Washington
- * Copyright 2013-2020 Eduardo Chappa
+ * Copyright 2013-2021 Eduardo Chappa
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -116,7 +116,7 @@ news_grouper(char *given_group, char **expanded_group, char **error,
 {
     char	 ng_error[90], *p1, *p2, *name, *end, *ep, **server,
 		 ng_ref[MAILTMPLEN];
-    int          expanded_len = 0, num_in_error = 0, cnt_errs;
+    int          expanded_len = 0, num_in_error = 0, cnt_errs = 0;
 
     MAILSTREAM  *stream = NULL;
     struct ng_list {
