@@ -5,7 +5,7 @@ static char rcsid[] = "$Id: save.c 1204 2009-02-02 19:54:23Z hubert@u.washington
 /*
  * ========================================================================
  * Copyright 2006-2009 University of Washington
- * Copyright 2013-2020 Eduardo Chappa
+ * Copyright 2013-2021 Eduardo Chappa
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -132,7 +132,7 @@ save_get_fldr_from_env(char *fbuf, int nfbuf, ENVELOPE *e, struct pine *state,
     char     fakedomain[2];
     ADDRESS *tmp_adr = NULL;
     char     buf[MAX(MAXFOLDER,MAX_NICKNAME) + 1];
-    char    *bufp;
+    char    *bufp = NULL;
     char    *folder_name = NULL;
     static char botch[] = "programmer botch, unknown message save rule";
     unsigned save_msg_rule;
@@ -425,7 +425,7 @@ save(struct pine *state, MAILSTREAM *stream, CONTEXT_S *context, char *folder,
     int           delete, filter, k, worry_about_keywords = 0;
     char	 *save_folder, *seq, *flags = NULL, date[64], tmp[MAILTMPLEN];
     long	  i, nmsgs, rawno;
-    size_t        len;
+    size_t        len = 0;
     STORE_S	 *so = NULL;
     MAILSTREAM	 *save_stream = NULL;
     MESSAGECACHE *mc;
@@ -504,7 +504,7 @@ save(struct pine *state, MAILSTREAM *stream, CONTEXT_S *context, char *folder,
 
 	if(dstn_stream && dstn_stream->kwd_create){
 	    imapuid_t dummy_uid = 0L;
-	    long dummy_msgno, delete_count;
+	    long dummy_msgno = 0L, delete_count;
 	    int expbits, set;
 	    char *flags = NULL;
 	    char *user_flag_name, *duser_flag_name;
@@ -564,7 +564,7 @@ save(struct pine *state, MAILSTREAM *stream, CONTEXT_S *context, char *folder,
 		char dummymsg[1000];
 		char *id = NULL;
 		char *idused;
-		appenduid_t *au;
+		appenduid_t *au = NULL;
 
 		newlen = strlen("\\DELETED");
 		len += newlen;
@@ -1602,6 +1602,7 @@ save_ex_explain_body(struct mail_bodystruct *body, long unsigned int *len, gf_io
       else
 	return(0);
 
+    ilen = 0;	/* maybe save_ex_explain_parts should set this to zero instead */
     if(!save_ex_explain_parts(body, 0, &ilen, pc))
       return(0);
 
@@ -1720,10 +1721,8 @@ save_ex_explain_parts(struct mail_bodystruct *body, int depth, long unsigned int
 int
 save_ex_output_text(char *text, int depth, unsigned long *len, gf_io_t pc)
 {
-   int starti, i, j, startpos, pos, rv;
-   int line_len = 68 - depth;
+   int starti, i, startpos, pos, rv;
    char tmp[100];	/* a number bigger than 68, we justify text here. */
-   char *s;
    unsigned long ilen;
 
    rv = 0;
@@ -1734,7 +1733,7 @@ save_ex_output_text(char *text, int depth, unsigned long *len, gf_io_t pc)
      startpos = pos;
      for(starti = i = depth; i < 68 && text[pos] != '\0'; i++, pos++){
 	tmp[i] = text[pos];
-	if(tmp[i] == ' '){				/* save when we reach a space */
+	if(tmp[i] == ' '){	/* save when we reach a space */
 	   starti = i;
 	   startpos = pos;
 	}
