@@ -4,7 +4,7 @@ static char rcsid[] = "$Id: smkeys.c 1266 2009-07-14 18:39:12Z hubert@u.washingt
 
 /*
  * ========================================================================
- * Copyright 2013-2020 Eduardo Chappa
+ * Copyright 2013-2021 Eduardo Chappa
  * Copyright 2008 University of Washington
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
@@ -201,7 +201,7 @@ ALPINE_self_signed_certificate(char *template, int version, char *pathdir, char
 	if((req = X509_REQ_new()) != NULL
 	    && X509_REQ_set_version(req, 0L)){
 	    name = X509_REQ_get_subject_name(req);
-	    X509_NAME_add_entry_by_txt(name, "CN", MBSTRING_ASC, "Password File Certificate and Key Pair", -1, -1, 0);
+	    X509_NAME_add_entry_by_txt(name, "CN", MBSTRING_ASC, (unsigned char *) "Password File Certificate and Key Pair", -1, -1, 0);
 	    if(X509_REQ_set_pubkey(req, pkey)
 		&& (pcert = X509_new()) != NULL){
 		if(X509_set_version(pcert, version)
@@ -241,7 +241,6 @@ ALPINE_self_signed_certificate(char *template, int version, char *pathdir, char
 	    build_path(tmp, pathdir, certfile, sizeof(tmp));
 	    if((fp = fopen(tmp, "w")) != NULL
 		&&(out = BIO_new_fp(fp, BIO_FP_TEXT)) != NULL){
-	      EVP_PKEY *tpubkey = X509_REQ_get0_pubkey(req);
 	      PEM_write_bio_X509(out, pcert);
 	      BIO_flush(out);
 	      BIO_free(out);
@@ -1054,8 +1053,11 @@ save_cert_for(char *email, X509 *cert, WhichCerts ctype)
 		}
 		else{
 		   if(strlen(path) + strlen(tempfile) - strlen(ret_dir) + 1 < sizeof(path))
-		     snprintf(fpath, sizeof(fpath), "%s%c%s", 
-			path, tempfile[strlen(ret_dir)], tempfile + strlen(ret_dir) + 1);
+		     snprintf(fpath, sizeof(fpath), "%.*s%c%.*s",
+			(int) strlen(path), path,
+			tempfile[strlen(ret_dir)],
+			(int) (sizeof(fpath) - strlen(fpath) - 1),
+			tempfile + strlen(ret_dir) + 1);
 		   else
 		     err++;
 		}
