@@ -4,7 +4,7 @@ static char rcsid[] = "$Id: string.c 910 2008-01-14 22:28:38Z hubert@u.washingto
 
 /*
  * ========================================================================
- * Copyright 2013-2020 Eduardo Chappa
+ * Copyright 2013-2021 Eduardo Chappa
  * Copyright 2006-2008 University of Washington
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
@@ -392,7 +392,7 @@ char *
 short_str(char *src, char *buf, size_t buflen, int wid, WhereDots where)
 {
     char *ans;
-    unsigned alen, first, second;
+    unsigned alen, first = 0, second = 0;
 
     if(wid <= 0){
 	ans = buf;
@@ -1309,7 +1309,7 @@ convert_date_to_local(char *date)
 {
     struct tm  *tm;
     time_t      ltime;
-    static char datebuf[26];
+    static char datebuf[30];
 
     ltime = date_to_local_time_t(date);
     if(ltime == (time_t) -1)
@@ -1425,7 +1425,7 @@ byte_string(long int bytes)
     char       *a, aa[5];
     char       *abbrevs = "GMK";
     long        i, ones, tenths;
-    static char string[10];
+    static char string[50];
 
     ones   = 0L;
     tenths = 0L;
@@ -1589,7 +1589,7 @@ fold(char *src, int width, int maxwidth, char *first_indent, char *indent, unsig
 	    }
 
 	    if(winner == -1 && (flags & FLD_NEXTSPC)){
-		for(i = starting_point; winner == -1 && i <= strlen(next_piece) != '\0' && i < 512; i++){
+		for(i = starting_point; winner == -1 && (i <= strlen(next_piece)) != '\0' && i < 512; i++){
 		    endptr = utf8_count_forw_width(next_piece, i, &got_width);
 		    if(endptr && got_width == i && isspace((unsigned char) *endptr))
 		      winner = (int) i;
