@@ -5,7 +5,7 @@ static char rcsid[] = "$Id: takeaddr.c 1012 2008-03-26 00:44:22Z hubert@u.washin
 /*
  * ========================================================================
  * Copyright 2006-2007 University of Washington
- * Copyright 2013-2020 Eduardo Chappa
+ * Copyright 2013-2021 Eduardo Chappa
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -529,7 +529,7 @@ set_up_takeaddr(int cmd, struct pine *ps, MSGNO_S *msgmap, TA_S **ta_ret,
 		int *selected_num, int flags, int (*att_addr_f)(TA_S *, int))
 {
     long      i;
-    ENVELOPE *env;
+    ENVELOPE *env = NULL;
     int       how_many_selected = 0,
 	      added, rtype = 0,
 	      we_cancel = 0,
