@@ -4,7 +4,7 @@ static char rcsid[] = "$Id: thread.c 942 2008-03-04 18:21:33Z hubert@u.washingto
 
 /*
  * ========================================================================
- * Copyright 2013-2020 Eduardo Chappa
+ * Copyright 2013-2021 Eduardo Chappa
  * Copyright 2006-2008 University of Washington
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
@@ -720,7 +720,7 @@ PINETHRD_S *
 msgno_thread_info(MAILSTREAM *stream, long unsigned int rawno,
 		  PINETHRD_S *attached_to_thrd, unsigned int flags)
 {
-    PINELT_S   **peltp;
+    PINELT_S   **peltp = NULL;
     MESSAGECACHE *mc;
 
     if(!stream || rawno < 1L || rawno > stream->nmsgs)
